@@ -301,7 +301,7 @@ def do_archive(archive_type, dump_path):
         return False, None
 
 
-def get_table_name_matches(conn, table_name_wildcard, separator):
+def get_table_name_matches(conn, table_name_wildcard):
     """
     Find tables to backup
     """
@@ -447,7 +447,6 @@ def delete_table(conn, sleep_interval: int, table_name: str):
                     time.sleep(sleep_interval)
             except conn.exceptions.ResourceNotFoundException:
                 logging.info(table_name + " table deleted.")
-                pass
             except conn.exceptions.ClientError as e:
                 logging.exception(e)
                 sys.exit(1)
@@ -461,9 +460,7 @@ def mkdir_p(path):
     try:
         os.makedirs(path)
     except OSError as exc:
-        if exc.errno == errno.EEXIST and os.path.isdir(path):
-            pass
-        else:
+        if not (exc.errno == errno.EEXIST and os.path.isdir(path)):
             raise
 
 
@@ -646,17 +643,19 @@ def do_empty(dynamo, table_name, billing_mode):
     )
 
 
-def do_backup(dynamo, read_capacity, tableQueue=None, srcTable=None, filterOption=None):
+def do_backup(
+    dynamo, read_capacity, table_queue=None, src_table=None, filter_option=None
+):
     """
-    Connect to DynamoDB and perform the backup for srcTable or each table in tableQueue
+    Connect to DynamoDB and perform the backup for src_table or each table in table_queue
     """
 
-    if srcTable:
-        table_name = srcTable
+    if src_table:
+        table_name = src_table
 
-    if tableQueue:
+    if table_queue:
         while True:
-            table_name = tableQueue.get()
+            table_name = table_queue.get()
             if table_name is None:
                 break
 
@@ -703,8 +702,8 @@ def do_backup(dynamo, read_capacity, tableQueue=None, srcTable=None, filterOptio
                         optional_args = {}
                         if last_evaluated_key is not None:
                             optional_args["ExclusiveStartKey"] = last_evaluated_key
-                        if filterOption is not None:
-                            optional_args.update(filterOption)
+                        if filter_option is not None:
+                            optional_args.update(filter_option)
                         scanned_table = dynamo.scan(
                             TableName=table_name, **optional_args
                         )
@@ -714,7 +713,7 @@ def do_backup(dynamo, read_capacity, tableQueue=None, srcTable=None, filterOptio
                             + table_name
                             + ".  BACKUP FOR IT IS USELESS."
                         )
-                        tableQueue.task_done()
+                        table_queue.task_done()
 
                     f = open(
                         args.dumpPath
@@ -758,7 +757,7 @@ def do_backup(dynamo, read_capacity, tableQueue=None, srcTable=None, filterOptio
                     + str(datetime.datetime.now().replace(microsecond=0) - start_time)
                 )
 
-            tableQueue.task_done()
+            table_queue.task_done()
 
 
 def prepare_provisioned_throughput_for_restore(provisioned_throughput):
@@ -1104,13 +1103,13 @@ def main():
     parser.add_argument(
         "-a",
         "--archive",
-        help="Type of compressed archive to create." "If unset, don't create archive",
+        help="Type of compressed archive to create. If unset, don't create archive",
         choices=["zip", "tar"],
     )
     parser.add_argument(
         "-b",
         "--bucket",
-        help="S3 bucket in which to store or retrieve backups." "[must already exist]",
+        help="S3 bucket in which to store or retrieve backups. [must already exist]",
     )
     parser.add_argument(
         "-m",
@@ -1133,10 +1132,10 @@ def main():
         "--port", help="Port of local DynamoDB [required only for local]"
     )
     parser.add_argument(
-        "--accessKey", help="Access key of local DynamoDB " "[required only for local]"
+        "--accessKey", help="Access key of local DynamoDB [required only for local]"
     )
     parser.add_argument(
-        "--secretKey", help="Secret key of local DynamoDB " "[required only for local]"
+        "--secretKey", help="Secret key of local DynamoDB [required only for local]"
     )
     parser.add_argument(
         "-p",
@@ -1160,7 +1159,7 @@ def main():
     )
     parser.add_argument(
         "--prefixSeparator",
-        help="Specify a different prefix separator, " "e.g. '.' [optional]",
+        help="Specify a different prefix separator, e.g. '.' [optional]",
     )
     parser.add_argument(
         "--noSeparator",
@@ -1230,7 +1229,7 @@ def main():
         default=str(PROVISIONED_BILLING_MODE),
     )
     parser.add_argument(
-        "--log", help="Logging level - DEBUG|INFO|WARNING|ERROR|CRITICAL " "[optional]"
+        "--log", help="Logging level - DEBUG|INFO|WARNING|ERROR|CRITICAL [optional]"
     )
     parser.add_argument(
         "-f",
@@ -1313,9 +1312,7 @@ def main():
                 args.profile, args.region, args.tag
             )
         elif args.srcTable.find("*") != -1:
-            matching_backup_tables = get_table_name_matches(
-                conn, args.srcTable, prefix_separator
-            )
+            matching_backup_tables = get_table_name_matches(conn, args.srcTable)
         elif args.srcTable:
             matching_backup_tables.append(args.srcTable)
 
@@ -1335,15 +1332,15 @@ def main():
                 do_backup(
                     conn,
                     args.read_capacity,
-                    tableQueue=None,
-                    filterOption=filter_option,
+                    table_queue=None,
+                    filter_option=filter_option,
                 )
             else:
                 do_backup(
                     conn,
                     args.read_capacity,
                     matching_backup_tables,
-                    filterOption=filter_option,
+                    filter_option=filter_option,
                 )
         except AttributeError:
             # Didn't specify srcTable if we get here
@@ -1351,11 +1348,11 @@ def main():
             q = Queue()
             threads = []
 
-            for i in range(MAX_NUMBER_BACKUP_WORKERS):
+            for _ in range(MAX_NUMBER_BACKUP_WORKERS):
                 t = threading.Thread(
                     target=do_backup,
                     args=(conn, args.readCapacity),
-                    kwargs={"tableQueue": q, "filterOption": filter_option},
+                    kwargs={"table_queue": q, "filter_option": filter_option},
                 )
                 t.start()
                 threads.append(t)
@@ -1366,7 +1363,7 @@ def main():
 
             q.join()
 
-            for i in range(MAX_NUMBER_BACKUP_WORKERS):
+            for _ in range(MAX_NUMBER_BACKUP_WORKERS):
                 q.put(None)
             for t in threads:
                 t.join()
@@ -1410,9 +1407,7 @@ def main():
             )
 
         if dest_table.find("*") != -1:
-            matching_destination_tables = get_table_name_matches(
-                conn, dest_table, prefix_separator
-            )
+            matching_destination_tables = get_table_name_matches(conn, dest_table)
             delete_str = ": " if args.dataOnly else " to be deleted: "
             logging.info(
                 "Found "
@@ -1505,9 +1500,7 @@ def main():
             )
     elif args.mode == "empty":
         if args.srcTable.find("*") != -1:
-            matching_backup_tables = get_table_name_matches(
-                conn, args.srcTable, prefix_separator
-            )
+            matching_backup_tables = get_table_name_matches(conn, args.srcTable)
             logging.info(
                 "Found "
                 + str(len(matching_backup_tables))
